@@ -1,6 +1,7 @@
 # -*- coding: utf-8 -*-
 import re
 import sys
+import requests
 
 from suite_py.lib import logger
 from suite_py.lib.handler import prompt_utils
@@ -39,7 +40,18 @@ class CreateBranch:
         user = self._youtrack.get_current_user()
         self._youtrack.assign_to(issue["id"], user["login"])
 
-        self._youtrack.update_state(issue["id"], self._config.youtrack["picked_state"])
+        try:
+            self._youtrack.update_state(
+                issue["id"], self._config.youtrack["picked_state"]
+            )
+        except requests.exceptions.HTTPError:
+            logger.error(
+                "There was a problem moving the issue to the 'picked state' on YouTrack"
+            )
+            logger.error(
+                f"Does your YouTrack board have a state called '{self._config.youtrack['picked_state']}'?"
+            )
+            sys.exit(-1)
 
     def _ask_card(self):
         return prompt_utils.ask_questions_input(
